@@ -10,14 +10,14 @@ use Encode;
 use Web::Scraper;
 use URI::Escape;
 
-our $BASE_URL = 'http://bbs.jjwxc.net';
+sub base_url { 'http://bbs.jjwxc.net' }
 
 sub charset { 'cp936' }
 
 sub site_type { 'tiezi' }
 
-sub parse_tiezi {
-  my ( $self, $h ) = @_;
+sub parse_novel {
+  my ( $self, $h , $r) = @_;
   my %t;
   for ( $$h ) {
     ( $t{title} )   = m{<td bgcolor="\#E8F3FF"><div [^>]+?style="float: left;">\s*主题：(.+?)\s*<font color="\#999999" size="-1">}s;
@@ -33,14 +33,14 @@ sub parse_tiezi {
   }
 
   return \%t;
-} ## end sub parse_tiezi
+} ## end sub parse_novel
 
-sub parse_tiezi_floors {
+sub parse_novel_item {
   my ( $self, $h ) = @_;
 
   my @floor;
-  while ( $$h =~ m#(<tr class="reply_\d+">\s+<td colspan="2">.*?<td><font color=99CC00 size="-1">.*?</tr>)#gis ) {
-    my $cell = $1;
+  my @cc = $$h =~ m#(<div id="topic">.*?</div>.*?<td class="authorname">.*?</tr>)#gis;
+  for my $cell (@cc) {
     next unless ( $cell );
 
     my %fl;
@@ -51,7 +51,7 @@ sub parse_tiezi_floors {
     $fl{writer} =~ s/^-*//;
     $fl{writer} ||= 'unknown';
 
-    ( $fl{content} ) = $cell =~ m{<tr>\s*<td[^>]*class="read">\s*<div id="topic">(.*?)\s*</div>\s*</td>\s*</tr>\s*</table>}s;
+    ($fl{content})=$cell=~m#<div id="topic">(.*?)</div>#s;
     for ( $fl{content} ) {
       s#本帖尚未审核,若发布24小时后仍未审核通过会被屏蔽##s;
       s#</?font[^>]*>##isg;
@@ -63,18 +63,19 @@ sub parse_tiezi_floors {
 
     push @floor, \%fl;
   } ## end while ( $$h =~ m#(<tr class="reply_\d+">\s+<td colspan="2">.*?<td><font color=99CC00 size="-1">.*?</tr>)#gis)
+  shift @floor;
 
   return \@floor;
-} ## end sub parse_tiezi_floors
+} ## end sub parse_novel_item
 
-sub parse_tiezi_list {
+sub parse_novel_list {
   my ( $self, $h ) = @_;
   my ( $page_info ) = $$h =~ m[<div id="pager_top" align="center" style="padding:10px;">(.+?)</div>]s;
   return unless ( $page_info );
 
   my ( $page_num, $page_url ) = $page_info =~ m[共(\d+)页.+?<a href=(.+?page=)\d]s;
   my @urls =
-    map { "$BASE_URL/showmsg.php$page_url$_" } ( 1 .. $page_num - 1 );
+    map { $self->base_url()."/showmsg.php$page_url$_" } ( 1 .. $page_num - 1 );
   return \@urls;
 }
 
@@ -85,7 +86,7 @@ sub parse_board {
   return $title;
 }
 
-sub parse_board_items {
+sub parse_board_item {
   my ( $self, $h ) = @_;
 
   my @tz_list =
@@ -100,7 +101,7 @@ sub parse_board_items {
 
     @temp{qw/writer/} = m{</td></tr></table></td>\s+<td>&nbsp;(.+?)</td>}s;
     @temp{qw/time/}   = m{<td align="center"><font size="-1">(.+?)</font></td>}s;
-    $temp{url}        = "$BASE_URL/$temp{url}";
+    $temp{url}        = $self->base_url()."/$temp{url}";
 
     $temp{writer} =~ s/<[^>]+>//sg;
     $temp{title} =~ s#</?font[^>]*>##gs;
@@ -110,28 +111,16 @@ sub parse_board_items {
   }
 
   return \@res;
-} ## end sub parse_board_items
+} ## end sub parse_board_item
 
 sub parse_board_list {
   my ( $self, $h ) = @_;
   my ( $u ) = $$h =~ m{href=(board.php\?[^>]+?page=)\d+\s+><img src="img/anniu1.gif" alt="下一页"}s;
   my ( $n ) = $$h =~ m{共<font color="\#FF0000">(\d+)</font>页}s;
   my @board_urls =
-    map { "$BASE_URL/$u$_" } ( 2 .. $n );
+    map { $self->base_url()."/$u$_" } ( 2 .. $n );
   return \@board_urls;
 }
-##-----------------------------------
-#sub parse_board_subboards {
-#my ( $self, $h ) = @_;
-#my ($jh) =
-#$$h =~ m{<a href="([^"]+?)" target="_blank">精华区</a>}s;
-#my ($th) =
-#$$h =~ m{<a href="([^"]+?)" target="_blank">套红区</a>}s;
-#my ($jx) =
-#$$h =~ m{<a href="([^"]+?)" target="_blank">加☆区</a>}s;
-#my @sub_board_urls = map { "$BASE_URL/$_" } ( $jh, $th, $jx );
-#return \@sub_board_urls;
-#} ## end sub parse_board_subboards
 
 sub make_query_request {
 
@@ -147,7 +136,7 @@ sub make_query_request {
   );
   my $type = $qt{ $opt{query_type} };
 
-  my $url = $BASE_URL . '/search.php?act=search';
+  my $url = $self->base_url() . '/search.php?act=search';
 
   #my $kw = uri_escape(encode($self->charset(),$keyword));
   my $post = {
@@ -163,7 +152,6 @@ sub make_query_request {
   my $post_str = $self->{browser}->format_post_content( $post );
 
   my $u = "$url&$post_str";
-  print $u, "\n";
   return $u;
 
 } ## end sub make_query_request
@@ -172,12 +160,12 @@ sub parse_query_list {
   my ( $self, $h ) = @_;
   my ( $page_num ) = $$h =~ m[var phpCount = (\d+);]si;
   my ( $url )      = $$h =~ m[id="selectpage" onChange="location.href='(.+?)'\+this.value">]si;
-  my @urls = map { encode( $self->charset(), "$BASE_URL$url$_" ) } ( 2 .. $page_num );
+  my @urls = map { encode( $self->charset(), $self->base_url()."$url$_" ) } ( 2 .. $page_num );
 
   return \@urls;
 }
 
-sub parse_query_items {
+sub parse_query_item {
   my ( $self, $h ) = @_;
   my $parse_query = scraper {
     process '//table[@cellpadding="2"]//tr', 'tzs[]' => scraper {
@@ -191,7 +179,7 @@ sub parse_query_items {
     my $r = $_->{info};
     s/^\s+|\s+$//g for @$r;
     $_->{url} =~ s/keyword=[^&]+&//;
-    { url    => "$BASE_URL/$_->{url}",
+    { url    => $self->base_url()."/$_->{url}",
       title  => $r->[1],
       writer => $r->[2],
       time_s => $r->[3],
@@ -203,6 +191,6 @@ sub parse_query_items {
     $_->{url}
     } @$ref;
   return \@data;
-} ## end sub parse_query_items
+} ## end sub parse_query_item
 
 1;
