@@ -5,11 +5,11 @@
 
 =head1 FUNCTION
 
-=head2 parse_index
+=head2 parse_novel
 
 解析raw 文件
   
-  my $raw_content_ref = $self->parse_index( '/someotherdir/somefile.raw' );
+  my $raw_content_ref = $self->parse_novel( '/someotherdir/somefile.raw' );
 
 =cut
 package Novel::Robot::Parser::raw;
@@ -17,15 +17,16 @@ use strict;
 use warnings;
 use base 'Novel::Robot::Parser';
 
-use File::Slurp;
+use File::Slurp qw/read_file/;
 use Data::MessagePack;
-use utf8;
+#use utf8;
 
-sub parse_index {
+sub parse_novel {
     my ($self, $raw_file) = @_;
+    $raw_file = $raw_file->[0] if(ref($raw_file) eq 'ARRAY');
     my $s = read_file( $raw_file, binmode => ':raw' ) ;
     my $mp = Data::MessagePack->new();
-    $mp->utf8(1);
+    $mp->utf8(0);
     my $up = $mp->unpack($s);
     return $up;
 }
