@@ -7,14 +7,14 @@ use base 'Novel::Robot::Parser';
 
 sub base_url {  'http://m.xiaoxiaoshuwu.com' }
 
-sub scrape_index { { 
+sub scrape_novel { { 
         book => { path=> '//h3' },
         writer => { regex => '是由作家(.+?)所作', }, 
     } }
 
-sub scrape_chapter_list { { path => '//ul[@class="chapter"]//a' } }
+sub scrape_novel_list { { path => '//ul[@class="chapter"]//a' } }
 
-sub scrape_chapter { {
+sub scrape_novel_item { {
         title => { path => '//div[@id="nr_title"]'}, 
         content=>{ path => '//div[@id="chapterContent"]', extract => 'HTML' }, 
     } }
