@@ -8,14 +8,14 @@ use base 'Novel::Robot::Parser';
 
 sub base_url {  'http://www.ybdu.com' }
 
-sub scrape_chapter_list { { path=>'//ul[@class="mulu_list"]//a'} }
+sub scrape_novel_list { { path=>'//ul[@class="mulu_list"]//a'} }
 
-sub scrape_index { {
+sub scrape_novel { {
         writer => { regex => '<meta property="og:novel:author" content="(.+?)"/>', }, 
         book=>{ regex => '<meta property="og:novel:book_name" content="(.+?)"/>', }, 
     } }
 
-sub scrape_chapter { {
+sub scrape_novel_item { {
         title => { path => '//div[@class="h1title"]//h1'}, 
         content=>{ path => '//div[@id="htmlContent"]', extract => 'HTML', sub => sub {
                 my ($c) = @_;
